==> frma_1.0.0.tgz: frma/doc/frma.R <==
###################################################
### chunk number 1: 
###################################################
library(frma)


###################################################
### chunk number 2: 
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="median_polish")


###################################################
### chunk number 3: 
###################################################
library(frma)


###################################################
### chunk number 4: 
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="robust_weighted_average")


###################################################
### chunk number 5: 
###################################################
library(frma)


###################################################
### chunk number 6: 
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="batch")


###################################################
### chunk number 7: 
###################################################
e <- exprs(object)


###################################################
### chunk number 8: 
###################################################
library(frma)


###################################################
### chunk number 9: 
###################################################
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample)


###################################################
### chunk number 10: 
###################################################
bc <- barcode(object)

==> frma_1.2.0.tgz: frma/doc/frma.R <==
###################################################
### chunk number 1: 
###################################################
#line 68 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
library(frma)


###################################################
### chunk number 2: 
###################################################
#line 72 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="median_polish")


###################################################
### chunk number 3: 
###################################################
#line 92 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
library(frma)


###################################################
### chunk number 4: 
###################################################
#line 96 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample, summarize="robust_weighted_average")


###################################################
### chunk number 5: 
###################################################
#line 116 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
##library(frma)


###################################################
### chunk number 6: 
###################################################
#line 120 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
##library(frmaExampleData)
##data(AffyBatchExample)
##object <- frma(AffyBatchExample, summarize="batch")


###################################################
### chunk number 7: 
###################################################
#line 130 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
e <- coefs(object)


###################################################
### chunk number 8: 
###################################################
#line 234 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
library(frma)


###################################################
### chunk number 9: 
###################################################
#line 238 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
library(frmaExampleData)
data(AffyBatchExample)
object <- frma(AffyBatchExample)


###################################################
### chunk number 10: 
###################################################
#line 244 "/private/tmp/RtmpBOFtE3/R.INSTALL3182320f/frma/inst/doc/frma.Rnw"
bc <- barcode(object)
